#!/bin/bash
#
#   USAGE:  buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof>

basequal=${1}
extras=${2}

pkgver=v4_9_5_p02

if [ -z ${basequal} ]
then
    echo "ERROR: please specify the base qualifier"
    echo "USAGE: buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof>"
    exit 1
fi

if [ "${extras}" = "debug" ]
then
    qual=${basequal}:debug
    qdir=${basequal}-debug
elif [ "${extras}" = "opt" ]
then
    qual=${basequal}:opt
    qdir=${basequal}-opt
elif [ "${extras}" = "prof" ]
then
    qual=${basequal}:prof
    qdir=${basequal}-prof
else
    echo "ERROR: please specify debug, opt, or prof"
    echo "USAGE: buildGeant4.sh <gcc46|gcc47|e2|supcl|f1> <debug|opt|prof>"
    exit 1
fi


source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
g4dir=${PRODUCTS}/geant4/${pkgver}/${flvr}-${qdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${g4dir}
if [ ! -d ${g4dir} ]
then
   echo "ERROR: failed to create ${g4dir}"
   exit 1
fi

# declare and then build geant4
echo "Declaring geant4 ${pkgver} for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare geant4 ${pkgver} -r geant4/${pkgver} -2 -m geant4.table -q ${qual}
else 
   ups declare geant4 ${pkgver} -r geant4/${pkgver} -4 -m geant4.table -q ${qual}
fi

echo "calling ups build geant4 ${pkgver} -q ${qual}"

ups build geant4 ${pkgver} -q ${qual}

# this should not complain
echo "Finished building geant4 ${pkgver} ${flvr} -q ${qual}"
setup geant4 ${pkgver} -q ${qual}

if [ ! -d ${G4LIB} ]
then
   echo "ERROR: failed to create ${G4LIB}"
   echo "       Something is very wrong"
   exit 1
fi
echo "G4LIB is ${G4LIB}"

exit 0
